from setuptools import setup

setup(name='jon_dist_prob',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author="Mukhammad Khalimudin",
      author_email="khalimudin@gmail.com",
      zip_safe=False)
